stackedCIF <- 
    function (x,
          group = 1,
            col = "black",
           fill = "white",
           ylim = c(0,1), 
           xlab = "Time",
           ylab = "Cumulative incidence",
            ... ) 
{
    ne <- ncol(x$pstate) - 1
    ng <- length(x$n)
    if (group %in% 1:ng) {
        r1 <- ifelse(group == 1 | ng == 1, 1, cumsum(x$strata)[group - 
            1] + 1)
        r2 <- ifelse(ng == 1, length(x$time), cumsum(x$strata)[group])
        pSt0 <- matrix(0, nrow = nrow(x$pstate[r1:r2, ]), ncol = ne + 
            2)
        pSt0[, 1] <- x$pstate[r1:r2, 1]
        for (c in 2:ne) pSt0[, c] <- pSt0[, c - 1] + x$pstate[r1:r2, 
            c]
        pSt0[, ne + 1] <- 1
        pSt0[, ne + 2] <- x$time[r1:r2]
        pSt <- cbind(0, pSt0)
        pSt2 <- matrix(0, nrow = 2 * (dim(pSt)[1] - 1), ncol = dim(pSt)[2])
        pSt2[1, ne + 3] <- pSt[1, ne + 3]
        pSt2[nrow(pSt2), ne + 3] <- pSt[nrow(pSt), ne + 3]
        for (j in 1:(dim(pSt)[1] - 1)) {
            pSt2[2 * j - 1,    ne + 3 ] <- pSt[j    ,    ne + 3 ]
            pSt2[2 * j       , ne + 3 ] <- pSt[j + 1,    ne + 3 ]
            pSt2[2 * j - 1, 1:(ne + 2)] <- pSt[j    , 1:(ne + 2)]
            pSt2[2 * j    , 1:(ne + 2)] <- pSt[j    , 1:(ne + 2)]
        }
        plot(as.numeric(pSt0[, ne + 2]), pSt0[, 2], type = "n", 
            ylim = ylim, yaxs = "i", xlab = xlab, ylab = ylab, 
            ...)
        for (i in 2:(ne + 1)) {
            polygon(c(pSt2[, ne + 3], rev(pSt2[, ne + 3])), c(pSt2[, 
                i], rev(pSt2[, i - 1])), col = fill[i - 1], border = NULL, 
                ...)
        }
        matlines( as.numeric(pSt0[, ne + 2]), pSt0[, 
            1:ne], type = "s", col = col)
        abline(v = max(x$time[r1:r2]), lwd = 2, col = "white")
        box()
    }
    else print(paste("Error: group indicator must be an integer from 1 to", 
        ng))
}


library(survival)   #  requires version 2.39-4 or later
head(mgus1)
#  Aalen-Johansen estimates of CIF are plotted by sex for two 
#  competing events: (1) progression (pcm), and (2) death, in 
#  a cohort of patients with monoclonal gammopathy.

#  The data are actually covering transitions from pcm to death, too,
#  for those entering the state of pcm. Such patients have two rows
#  in the data frame, and in their 2nd row the 'start' time is 
#  the time to pcm (in days). 

#  In our analysis we shall only include those time intervals with value 0
#  for variable 'start'. Thus, the relevant follow-up time is represented 
#  by variable 'stop' (days). For convenience, days are converted to years.

fitCI <- survfit(Surv(stop/365.25, event, type="mstate") ~ sex,
              data= subset(mgus1, start==0) )

par(mfrow=c(1,2))

stackedCIF(fitCI, group = 1, 
  main = "Women", xlab="Time (years)" )	
text( 36, 0.15, "PCM", pos = 2)
text( 36, 0.6, "Death", pos = 2)

col <- c("red", "blue")
stackedCIF(fitCI, group = 2, fill = c("gray80", "gray90"), 
  col = col, main = "Men", xlab="Time (years)" )
text( 39, 0.10, "PCM", pos = 2)
text( 39, 0.6, "Death", pos = 2)	

 
